pub struct CsvEncoder { /* private fields */ }Available on crate feature
csv only.Expand description
CsvEncoder implements Encoder with a CSV writer.
Implementations
Sourceimpl CsvEncoder
impl CsvEncoder
Sourcepub fn skip_header(self) -> Self
pub fn skip_header(self) -> Self
Whether to skip writing a header row in the first part.
By default a header row is written as the first row in the first part.
Sourcepub fn escape_quotes(self) -> Self
pub fn escape_quotes(self) -> Self
When there are quotes in field data, escape them instead of writing double quotes.
By default, quotes in fields are converted to "". With this enabled,
this instead becomes \".