pub struct Error(/* private fields */);Expand description
The value returned when some operation in this crate fails.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn failed_upload(&self) -> Option<&FailedUpload>
pub fn failed_upload(&self) -> Option<&FailedUpload>
Returns the details of the upload that failed if available.
Sourcepub fn from_std<E>(e: E) -> Self
pub fn from_std<E>(e: E) -> Self
Convert an arbitrary std::error::Error to this error type.