PartNumber

Struct PartNumber 

pub struct PartNumber(/* private fields */);
Number we assign to a part when uploading.

This, along with the entity tag found in the response, is required in the request to complete a multipart upload because it identifies the where the part goes when assembling the full object.

The Default behavior is to start with the part number 1. This is because it is a requirement of the API that a part number be an integer between 1 and 10,000.

Implementations

Source

impl PartNumber

pub fn new() -> Self

Initializes the part number at 1, which is a requirement of the API.

pub fn start_with(n: i32) -> Self

Create a new PartNumber starting with n.

Used when resuming an upload that was suspended with completed parts.

For a new upload, use Self::new.

pub fn is_first(&self) -> bool

Returns whether this is the first part of an upload.

pub fn is_valid(&self) -> bool

Returns whether this is a valid part according to API specification.

pub fn fetch_incr(&mut self) -> PartNumber

Increment the PartNumber by 1, returning the previous part number.

Methods from Deref<Target = i32>

1.43.0 · Source

pub const MIN: i32

1.43.0 · Source

pub const MAX: i32

1.53.0 · Source

pub const BITS: u32 = u32::BITS