pub struct Uploaded {
pub uri: ObjectUri,
pub etag: EntityTag,
pub bytes: u64,
pub parts: u64,
pub items: Option<u64>,
pub duration: Duration,
}Expand description
Value returned by multipart uploads when polled for completion.
Fields
uri: ObjectUriThe uploaded object’s URI.
etag: EntityTagThe entity tag of the uploaded object.
bytes: u64Size in bytes of the upload.
parts: u64Number of parts that went into the upload.
items: Option<u64>Number of items that went into the upload, if known.
duration: DurationTotal duration of the multipart upload.