pub struct EncoderStatus {
pub upload_bytes: u64,
pub total_bytes: u64,
pub total_parts: u64,
pub total_items: u64,
pub part_bytes: u64,
pub part_items: u64,
pub duration: Duration,
pub should_send: bool,
pub should_complete: bool,
}Expand description
Returned by WithPartEncoder when writing an item was successful.
Fields
upload_bytes: u64Last recorded size in bytes of all parts that have been added to the upload successfully.
total_bytes: u64Total size in bytes of all items that have been written.
total_parts: u64Total number of parts that have been written.
total_items: u64Total number of items that have been written.
part_bytes: u64Size in bytes of the current part.
part_items: u64Number of items written to the current part.
duration: DurationTotal duration of this upload.
should_send: boolWhether the current part should be sent.
should_complete: boolWhether the current upload should be completed.