Upload

Struct Upload 

pub struct Upload { /* private fields */ }
Upload manages the lifecycle of an AWS S3 multipart upload.

This type realizes MultipartWrite through the following:

  • poll_ready ensures that there is a valid, active multipart upload, and that the number of pending part upload requests does not exceed configured capacity.
  • start_send accepts a PartBody, creates a part upload request future from it, and pushes it to a collection of these, where the responses are resolved asynchronously and independently. Current statistics of the upload are returned in the value UploadStatus.
  • poll_flush awaits all pending part upload request futures, draining the collection.
  • poll_complete flushes and then submits the request to complete the multipart upload, returning the response as the value Uploaded.

On completion, a new upload is started if possible. This relies on the ability of the ObjectUriIter that it was created with to generate the next upload URI. Polling for readiness ensures that the new upload has resolved to an upload ID before allowing start_send.

Fusing

If ObjectUriIter::next ever produces None, the multipart upload will transition to a terminated state and it is not polled again.