pub struct UploadStatus {
pub upload_bytes: u64,
pub total_bytes: u64,
pub total_parts: u64,
pub duration: Duration,
pub should_complete: bool,
}Expand description
Returned by Upload when sending a part was successful.
Fields
upload_bytes: u64Last recorded size in bytes of all parts that have been added to the upload successfully.
total_bytes: u64Total size in bytes of all parts that have been sent.
total_parts: u64Total number of parts that have been sent.
duration: DurationTotal duration of this upload.
should_complete: boolWhether the current upload should be completed.