pub struct PartNumber(/* private fields */);Expand description
Number we assign to a part when uploading.
This, along with the entity tag found in the response, is required in the request to complete a multipart upload because it identifies the where the part goes when assembling the full object.
The Default behavior is to start with the part number 1. This is
because it is a requirement of the API that a part number be an integer
between 1 and 10,000.
Implementations
Sourceimpl PartNumber
impl PartNumber
Sourcepub fn start_with(n: i32) -> Self
pub fn start_with(n: i32) -> Self
Create a new PartNumber starting with n.
Used when resuming an upload that was suspended with completed parts.
For a new upload, use Self::new.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns whether this is a valid part according to API specification.
Sourcepub fn fetch_incr(&mut self) -> PartNumber
pub fn fetch_incr(&mut self) -> PartNumber
Increment the PartNumber by 1, returning the previous part number.